%% figures_1_and_7.m
% Creates the figures and the data results (the covariances between unemployment rate
% and share on temporary layoff) used in the section on temporary layoffs
% in Ravenna and Walsh, Worker heterogeneity, selection, and employment dynamics 
% in a pandemic," JMCB forthcoming
% September 2021
%
% Data imported from the following spreadsheet:
%
%    Workbook: WHandCOVID_data20210406.xlsx
%    Worksheets: Monthly
%
clear all
close all
clc
% -------------------------------------------------------
%% housekeeping - options and sepecifies computer and file locations
%  
savefig   = 'yes'; % 'yes' to save figures
% --------------------------------------------------------
%% Import options and import the monthly data
opts            = spreadsheetImportOptions("NumVariables", 21);
opts.Sheet      = "Monthly";
opts.DataRange  = "A266:U880"; % starts in Jan 1970 (row 266), ends Mar 2021 (row 880)
%
% Specify column names and types
%                      DATE	   CE16OV	EMRATIO	    LNS13008397
%                      LNS13023622	  LNS13023653	LNS13023654	    LNS13025699	    LNS13025701	  LNS13026511	LNS13026638	    LNS14024887	    UNEMPLOY	UNRATE	U4RATE	U5RATE	JTSJOL	JTSLDL 
opts.VariableNames = ["DATE", "CE16OV", "EMRATIO", "JTSJOL", "JTSLDL", "JTSTSL", "LNS13008397", "LNS13023622", "LNS13023653", "LNS13023654", "LNS13025699", "LNS13025701", "LNS13026511", "LNS13026638", "LNS14024887", "PCEPILFE", "PSAVERT", "U4RATE", "U5RATE", "UNEMPLOY", "UNRATE"];

opts.VariableTypes = ["datetime", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double"];

% Specify variable properties
opts = setvaropts(opts, "DATE", "InputFormat", "");

% Import the data
CPS = readtable("WHandCOVID_data20210406.xlsx", opts, "UseExcel", false);

% Clear temporary variables
clear opts
% -----------------------------------------------
%% rename variables
tempshare = CPS.LNS13023654;
permshare = CPS.LNS13026511;
unrate    = CPS.UNRATE;
u4        = CPS.U4RATE;
u5        = CPS.U5RATE;
vacancies = CPS.JTSJOL;
layoffs   = CPS.JTSLDL;
separat   = CPS.JTSTSL;
savert    = CPS.PSAVERT;
empop     = CPS.EMRATIO;
employ    = CPS.CE16OV;
daten     = datenum(CPS.DATE);
T         = length(tempshare);
for j = 13:T;
    inflyoy(j,1)   = 100*(CPS.PCEPILFE(j)-CPS.PCEPILFE(j-12))/CPS.PCEPILFE(j-12);
end
inflyoy(1:12,1) = nan;
% --------------------------------------------------------
%% observation numbers (note: inflyoy starts with obs. 13, Jan 1991
Jan1970 = 1;
Jan1985 = 181; 
Jan2000 = 361;
Dec2007 = 456;
Fed2020 = 602;
Apr2020 = 604;
Dec2019 = 600;
Feb2020 = 602;
Jan2021 = T;
temp_ave  = mean(tempshare(1:T,1));
temp_mean = temp_ave*ones(T,1);
perm_ave  = mean(permshare(1:T,1));
perm_mean = perm_ave*ones(T,1);
disp('.................')
disp('figures for average share of job lossers on layoff in section 4')
display(['average share of unemployed, job lossers on temp layoff Jan 2000 to Dec 2019: ',num2str(mean(tempshare(Jan2000:Dec2019)))])
display(['average share of unemployed, job lossers not on temp layoff Jan 2000 to Dec 2019: ',num2str(mean(permshare(Jan2000:Dec2019)))])
display(['peak share on temporary layoff (April 2020) was ',num2str(tempshare(604))])
disp('.................')
display(['average share of unemployed, job lossers on temp layoff Jan 1970 to Mar 2021: ',num2str(temp_ave)])
display(['average share of unemployed, job lossers not on temp layoff Jan 1970 to Mar 2021: ',num2str(perm_ave)])
disp('................')

%% covariances
CPS.DATE([1 Jan1985 Dec2019 Feb2020 T])
covtempu1 = cov(tempshare(Jan1985:Dec2019,1),unrate(Jan1985:Dec2019,1));
covtempu2 = cov(tempshare(Jan1985:Dec2019+12,1),unrate(Jan1985:Dec2019+12,1));
covtempu3 = cov(tempshare(Jan1985:T,1),unrate(Jan1985:T,1));
% correlation coefficients
corre1 = corrcoef(tempshare(Jan1985:Dec2019,1),unrate(Jan1985:Dec2019,1));
corre2 = corrcoef(tempshare(Jan1985:Dec2019+12,1),unrate(Jan1985:Dec2019+12,1));
corre3 = corrcoef(tempshare(Jan1985:T,1),unrate(Jan1985:T,1));
disp('.......................')
display(['covariance between tempshare and unrate Jan 1985-Dec2019= ',num2str(covtempu1(1,2))])
display(['covariance between tempshare and unrate Jan 1985-Dec2020= ',num2str(covtempu2(1,2))])
display(['covariance between tempshare and unrate Jan 1985-Jan2021= ',num2str(covtempu3(1,2))])
disp('.......................')
display(['correlation coef between tempshare and unrate Jan 1985-Dec2019= ',num2str(corre1(1,2))])
display(['correlation coef between tempshare and unrate Jan 1985-Dec2020= ',num2str(corre2(1,2))])
display(['correlation coef between tempshare and unrate Jan 1985-Jan2021= ',num2str(corre3(1,2))])
disp('.......................')

%% Figure 1: comparing Great Recession and COVID
N = 12;
stgr = Dec2007;
for i = 1:N 
    empopGR(i) = empop(stgr+i-1)/empop(stgr);
    unGR(i)    = unrate(stgr+i-1)/unrate(stgr);
    vacGR(i)   = vacancies(stgr+i-1)/vacancies(stgr);
    layGR(i)   = layoffs(stgr+i-1)/layoffs(stgr);
    sepGR(i)   = separat(stgr+i-1)/separat(stgr);
    srtGR(i)   = savert(stgr+i-1)/savert(stgr);  
    inflGR(i)  = inflyoy(stgr+i-1)/inflyoy(stgr);
end
stco = Feb2020-1;
for i = 1:N % % allows for Mar2020 to Jan2021
    empopCOVID(i) = empop(stco+i-1)/empop(stco);
    unCOVID(i)    = unrate(stco+i-1)/unrate(stco);
    vacCOVID(i)   = vacancies(stco+i-1)/vacancies(stco);
    layCOVID(i)   = layoffs(stco+i-1)/layoffs(stco);
    sepCOVID(i)   = separat(stco+i-1)/separat(stco);
    srtCOVID(i)   = savert(stco+i-1)/savert(stco);
    inflCOVID(i)  = inflyoy(stco+i-1)/inflyoy(stco);
end
o   = ones(length(unCOVID));

%% Figure 1 in paper comparative figures
index = 1:N; index = index';
kr = 2; % subplot rows
kc = 2; % subplot columns
kk = kr*kc; % number of subplots
figure(1)
subplot(kr,kc,1)
plot(index,empopGR,'b-d',index,empopCOVID,'r--o',index,o,'k','LineWidth',1.5)
ylabel('Employment-to-Pop')
xlabel('months')
grid
axis([1 N 0.8 1.01]);
subplot(kr,kc,2)
plot(index,layGR,'b-d',index,layCOVID,'r--o',index,o,'k','LineWidth',1.25)
%axis tight
legend('GFC','COVID','Location','NorthEast')
grid
axis([1 N -0.5 8]); % tight
ylabel('Layoffs and discharges')
xlabel('months')

subplot(kr,kc,3)
plot(index,srtGR,'b-d',index,srtCOVID,'r--o',index,o,'k','LineWidth',1.25)
ylabel('Private saving rate')
xlabel('months')
grid
axis([1 N -Inf Inf]);
subplot(kr,kc,4)
plot(index,inflGR,'b-d',index,inflCOVID,'r--o',index,o,'k','LineWidth',1.25)
ylabel('Core PCE Inflation (yoy)')
xlabel('months')
grid
axis([1 N -Inf Inf]);
if strcmp(savefig,'yes')
    print -depsc2 'figure_1_macro_measures';
end

%% Figure 7; share of job losers on temp. layoff
st  = Jan2000;
figure(7)
subplot(2,1,1)
plot(daten(st:T,1),tempshare(st:T,1),'b',daten(st:T,1),permshare(st:T,1),'k--','LineWidth',1.25)
%legend('on temp. layoff','not on temp. layoff','Location','NorthWest')
text(daten(T-105),50,'not on temp. layoff')
text(daten(T-105),17,'on temp. layoff')
datetick('x',28)
if strcmp(savefig,'no')  
    title('Shares of total unemployment: Jan 2000 - Mar 2021')   
end
axis tight
nberdates_shading;

Jan2020 = Jan2021-12;
st      = Dec2019;
subplot(2,1,2)
plot(daten(st:T,1),tempshare(st:T,1),'b',daten(st:T,1),permshare(st:T,1),'k--','LineWidth',1.25)
text(daten(T-9),17,'not on temp. layoff')
text(daten(T-8),60,'on temp. layoff')
axis tight
nberdates_shading;
datetick('x',12,'keeplimits')

if strcmp(savefig,'yes')
    print -depsc2 'figure7_temp_and_perm_shares';
else
%    title('Shares of total unemployment: Jan 2020 - Mar 2021')   
end

